flutter_widget_to_marker_one library

Functions

convertWidgetToBitmapDescriptor(Widget widget, {Size size = const Size.square(100), double pixelRatio = 1.0, required BuildContext context}) Future<BitmapDescriptor>
Converts a Flutter Widget into a BitmapDescriptor that can be used as a marker icon in Google Maps.
convertWidgetToMarker({required String markerId, required LatLng position, required Widget widget, required BuildContext context, Size size = const Size.square(100), double pixelRatio = 1.0, Offset anchor = const Offset(0.5, 0.5), bool draggable = false, bool flat = false, bool visible = true, double zIndex = 0.0, double rotation = 0.0, void onTap()?, void onDragStart(LatLng)?, void onDrag(LatLng)?, void onDragEnd(LatLng)?}) Future<Marker>
Creates a Google Maps Marker from a Flutter Widget.